@@ -1,31 +1,73 @@
-( cd opt/kde/share/doc/HTML/sl/kdm ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kdm ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kppp ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kppp ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kdesu ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kdesu ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kfind ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kfind ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kpackage ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kpackage ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/khelpcenter ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/khelpcenter/userguide ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kioslave ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kioslave ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kaddressbook ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf fdl-license )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/fdl-license fdl-license )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf qpl-license.html )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf x11-license.html )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/blockdevices ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/processor ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/dma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/scsi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/samba ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/protocols ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/sound ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/pci ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/partitions ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/pcmcia ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/xserver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/laptop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/powerctrl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmlowbatcrit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmlowbatwarn ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/kalarmd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/kwindecoration ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/crypto ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/smb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmcss ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/clock ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/cookies ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/ebrowsing ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/keyboard ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmsmserver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/filetypes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/windowmanagement ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmlaunch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/arts ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/spellchecking ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/bell ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/kmixcfg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf 1.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/1.png 1.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf xml.dcl )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf 10.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/10.png 10.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf 2.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/2.png 2.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf 3.png )
@@ -42,135 +84,103 @@
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/8.png 8.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf 9.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/9.png 9.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf headerbg.png )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf gpl-license.html )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf mainheader.html )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf grad.png )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/grad.png grad.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kde-web.css )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kde_logo_bg.png )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf lgpl-license.html )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf doxygen.css )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf web-doctop.png )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kde-default.css )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kmenu.png )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf footer.html )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/footer.html footer.html )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kde-common.css )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf appheader.html )
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/appheader.html appheader.html )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf doctop1.png )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf doctop2.png )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf shadow.png )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/shadow.png shadow.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kde_logo.png )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf docheadergears.png )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf fdl-license.html )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf doctop1a.png )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf 10.png )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/10.png 10.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf doctop1b.png )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf lgpl-license )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf mainfooter.html )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf artistic-license.html )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf bottom-left.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf bottom-middle.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf bottom-right.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf bottom1.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf bottom2.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf header.html )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/header.html header.html )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf gpl-license )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/gpl-license gpl-license )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kde-localised.css.template )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf bsd-license.html )
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf docheadergears.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf doctop1.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf doctop1a.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf doctop1b.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf doctop2.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf doxygen.css )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf fdl-license )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/fdl-license fdl-license )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf fdl-license.html )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf footer.html )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/footer.html footer.html )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf gpl-license )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/gpl-license gpl-license )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf gpl-license.html )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf grad.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/grad.png grad.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf header.html )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/header.html header.html )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf headerbg.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kde-common.css )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kde-default.css )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kde-localised.css.template )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kde-web.css )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf kmenu.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf lgpl-license )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf lgpl-license.html )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf mainfooter.html )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf mainheader.html )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf qpl-license.html )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf shadow.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf top-left.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/top-left.png top-left.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf top-middle.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf top-right-konqueror.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; rm -rf web-docbottom.png )
 ( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
-( cd opt/kde/share/doc/HTML/sl/common ; rm -rf artistic-license.html )
-( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/smb ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/spellchecking ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/bell ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/arts ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/powerctrl ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/kalarmd ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/cookies ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/filetypes ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/clock ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/kmixcfg ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/ebrowsing ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/crypto ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmlaunch ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmcss ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/laptop ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmsmserver ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/windowmanagement ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/kwindecoration ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmlowbatcrit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmlowbatwarn ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/keyboard ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/dma ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/pci ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/scsi ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/blockdevices ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/xserver ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/samba ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/sound ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/partitions ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/pcmcia ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/processor ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/protocols ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf web-doctop.png )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf x11-license.html )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
+( cd opt/kde/share/doc/HTML/sl/common ; rm -rf xml.dcl )
+( cd opt/kde/share/doc/HTML/sl/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
+( cd opt/kde/share/doc/HTML/sl/kaddressbook ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kpackage ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kpackage ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kppp ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kppp ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/khelpcenter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/khelpcenter/userguide ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kdesu ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kdesu ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kdm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kdm ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
+( cd opt/kde/share/doc/HTML/sl/kfind ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sl/kfind ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
